pub struct SparseMemory<R> { /* private fields */ }
A sparse flat memory implementation, it allocates pages only when requested,
but besides that, it does not permission checking.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.