pub trait Machine: CoreMachine {
// Required methods
fn ecall(&mut self) -> Result<(), Error>;
fn ebreak(&mut self) -> Result<(), Error>;
}Expand description
This is the core trait describing a full RISC-V machine. Instruction package only needs to deal with the functions in this trait.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".